@@ -36,6 +36,8 @@ import org.uberfire.ext.wires.core.grids.client.model.GridCell;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseBounds;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCell;
+import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridTest;
@@ -53,6 +55,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
+import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.spy;
@@ -101,6 +104,8 @@ public class BaseCellSelectionManagerTest {
                                                                                     100));
     private GridColumn<String> col2 = spy(new BaseGridTest.MockMergableGridColumn<>("col2",
                                                                                     100));
+    private GridColumn<String> col3 = spy(new BaseGridTest.MockMergableGridColumn<>("col3",
+                                                                                    100));
 
     private Bounds visibleBounds = new BaseBounds(-1000,
                                                   -1000,
@@ -116,6 +121,7 @@ public class BaseCellSelectionManagerTest {
         gridWidgetData.appendRow(new BaseGridRow(ROW_HEIGHT));
         gridWidgetData.appendColumn(col1);
         gridWidgetData.appendColumn(col2);
+        gridWidgetData.appendColumn(col3);
 
         when(gridWidget.getModel()).thenReturn(gridWidgetData);
 
@@ -125,7 +131,7 @@ public class BaseCellSelectionManagerTest {
         when(gridWidget.getRenderer()).thenReturn(gridWidgetRenderer);
         when(gridWidget.getRendererHelper()).thenReturn(gridWidgetRendererHelper);
         when(gridWidget.getLayer()).thenReturn(gridLayer);
-        when(gridWidget.getWidth()).thenReturn(200.0);
+        when(gridWidget.getWidth()).thenReturn(300.0);
         when(gridWidget.getHeader()).thenReturn(gridWidgetHeader);
         when(gridWidget.getHeight()).thenReturn(HEADER_HEIGHT + (ROW_HEIGHT * 2));
         when(gridWidget.getViewport()).thenReturn(viewport);
@@ -251,7 +257,7 @@ public class BaseCellSelectionManagerTest {
     @Test
     public void selectCellColumnCoordinateGreaterThanColumnCount() {
         cellSelectionManager.selectCell(0,
-                                        2,
+                                        3,
                                         false,
                                         false);
 
@@ -378,6 +384,47 @@ public class BaseCellSelectionManagerTest {
                      gridWidgetData.getSelectedCellsOrigin());
     }
 
+    @Test
+    public void adjustSelectionLeftAndFindVisible() {
+        // DROOLS-5442
+        when(col2.isVisible()).thenReturn(false);
+
+        cellSelectionManager.selectCell(0,
+                                        2,
+                                        false,
+                                        false);
+        cellSelectionManager.adjustSelection(SelectionExtension.LEFT,
+                                             false);
+
+        final List<GridData.SelectedCell> selectedCells = gridWidgetData.getSelectedCells();
+        assertEquals(1,
+                     selectedCells.size());
+        assertTrue(selectedCells.contains(new GridData.SelectedCell(0,
+                                                                    0)));
+        assertEquals(new GridData.SelectedCell(0,
+                                               0),
+                     gridWidgetData.getSelectedCellsOrigin());
+    }
+
+    @Test
+    public void adjustSelectionLeftOutOfBound() {
+        cellSelectionManager.selectCell(0,
+                                        0,
+                                        false,
+                                        false);
+        cellSelectionManager.adjustSelection(SelectionExtension.LEFT,
+                                             false);
+
+        final List<GridData.SelectedCell> selectedCells = gridWidgetData.getSelectedCells();
+        assertEquals(1,
+                     selectedCells.size());
+        assertTrue(selectedCells.contains(new GridData.SelectedCell(0,
+                                                                    0)));
+        assertEquals(new GridData.SelectedCell(0,
+                                               0),
+                     gridWidgetData.getSelectedCellsOrigin());
+    }
+
     @Test
     public void adjustSelectionLeftWithShiftKey() {
         cellSelectionManager.selectCell(0,
@@ -418,6 +465,47 @@ public class BaseCellSelectionManagerTest {
                      gridWidgetData.getSelectedCellsOrigin());
     }
 
+    @Test
+    public void adjustSelectionRightAndFindVisible() {
+        // DROOLS-5442
+        when(col2.isVisible()).thenReturn(false);
+
+        cellSelectionManager.selectCell(0,
+                                        0,
+                                        false,
+                                        false);
+        cellSelectionManager.adjustSelection(SelectionExtension.RIGHT,
+                                             false);
+
+        final List<GridData.SelectedCell> selectedCells = gridWidgetData.getSelectedCells();
+        assertEquals(1,
+                     selectedCells.size());
+        assertTrue(selectedCells.contains(new GridData.SelectedCell(0,
+                                                                    2)));
+        assertEquals(new GridData.SelectedCell(0,
+                                               2),
+                     gridWidgetData.getSelectedCellsOrigin());
+    }
+
+    @Test
+    public void adjustSelectionRightOutOfBound() {
+        cellSelectionManager.selectCell(0,
+                                        2,
+                                        false,
+                                        false);
+        cellSelectionManager.adjustSelection(SelectionExtension.RIGHT,
+                                             false);
+
+        final List<GridData.SelectedCell> selectedCells = gridWidgetData.getSelectedCells();
+        assertEquals(1,
+                     selectedCells.size());
+        assertTrue(selectedCells.contains(new GridData.SelectedCell(0,
+                                                                    2)));
+        assertEquals(new GridData.SelectedCell(0,
+                                               2),
+                     gridWidgetData.getSelectedCellsOrigin());
+    }
+
     @Test
     public void adjustSelectionRightWithShiftKey() {
         cellSelectionManager.selectCell(0,
@@ -691,11 +779,11 @@ public class BaseCellSelectionManagerTest {
         cellSelectionManager.startEditingCell(editedAtPoint);
 
         verify(col2,
-               times(1)).edit(any(GridCell.class),
+               times(1)).edit(any(),
                               contextArgumentCaptor.capture(),
                               any(Consumer.class));
         verify(col2,
-               times(1)).edit(any(GridCell.class),
+               times(1)).edit(any(),
                               editContextArgumentCaptor.capture(),
                               any(Consumer.class));
 
@@ -753,11 +841,11 @@ public class BaseCellSelectionManagerTest {
                                               1);
 
         verify(col2,
-               times(1)).edit(any(GridCell.class),
+               times(1)).edit(any(),
                               contextArgumentCaptor.capture(),
                               any(Consumer.class));
         verify(col2,
-               times(1)).edit(any(GridCell.class),
+               times(1)).edit(any(),
                               editContextArgumentCaptor.capture(),
                               any(Consumer.class));
 
@@ -772,4 +860,101 @@ public class BaseCellSelectionManagerTest {
 
         cellSelectionManager.startEditingCell(new Point2D(10, HEADER_HEIGHT + 1));
     }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testGridBodyCellEditContextConstruction() {
+        final GridCell<String> cell = new BaseGridCell<>(new BaseGridCellValue<>("value"));
+
+        gridWidgetData.setCell(0, 1, () -> cell);
+
+        cellSelectionManager.startEditingCell(0, 1);
+
+        verify(col2).edit(eq(cell),
+                          editContextArgumentCaptor.capture(),
+                          any(Consumer.class));
+
+        assertGridBodyCellEditContext(editContextArgumentCaptor.getValue(),
+                                      0,
+                                      1,
+                                      ROW_HEIGHT,
+                                      col2.getWidth(),
+                                      GRID_ABSOLUTE_Y + HEADER_HEIGHT,
+                                      GRID_ABSOLUTE_X + col1.getWidth(),
+                                      GRID_ABSOLUTE_Y + HEADER_HEIGHT,
+                                      visibleBounds.getX());
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testGridBodyCellEditContextConstructionWithMergedCells() {
+        final GridCell<String> cell1 = new BaseGridCell<>(new BaseGridCellValue<>("value"));
+        final GridCell<String> cell2 = new BaseGridCell<>(new BaseGridCellValue<>("value"));
+
+        gridWidgetData.setMerged(true);
+        gridWidgetData.setCell(0, 1, () -> cell1);
+        gridWidgetData.setCell(1, 1, () -> cell2);
+
+        cellSelectionManager.startEditingCell(0, 1);
+
+        verify(col2).edit(eq(cell1),
+                          editContextArgumentCaptor.capture(),
+                          any(Consumer.class));
+
+        assertGridBodyCellEditContext(editContextArgumentCaptor.getValue(),
+                                      0,
+                                      1,
+                                      ROW_HEIGHT * 2,
+                                      col2.getWidth(),
+                                      GRID_ABSOLUTE_Y + HEADER_HEIGHT,
+                                      GRID_ABSOLUTE_X + col1.getWidth(),
+                                      GRID_ABSOLUTE_Y + HEADER_HEIGHT,
+                                      visibleBounds.getX());
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testGridBodyCellEditContextConstructionWithMergedCellsProgrammaticEditingCollapsedCell() {
+        final GridCell<String> cell1 = new BaseGridCell<>(new BaseGridCellValue<>("value"));
+        final GridCell<String> cell2 = new BaseGridCell<>(new BaseGridCellValue<>("value"));
+
+        gridWidgetData.setMerged(true);
+        gridWidgetData.setCell(0, 1, () -> cell1);
+        gridWidgetData.setCell(1, 1, () -> cell2);
+
+        cellSelectionManager.startEditingCell(1, 1);
+
+        verify(col2).edit(eq(cell2),
+                          editContextArgumentCaptor.capture(),
+                          any(Consumer.class));
+
+        assertGridBodyCellEditContext(editContextArgumentCaptor.getValue(),
+                                      1,
+                                      1,
+                                      ROW_HEIGHT * 2,
+                                      col2.getWidth(),
+                                      GRID_ABSOLUTE_Y + HEADER_HEIGHT,
+                                      GRID_ABSOLUTE_X + col1.getWidth(),
+                                      GRID_ABSOLUTE_Y + HEADER_HEIGHT,
+                                      visibleBounds.getX());
+    }
+
+    private void assertGridBodyCellEditContext(final GridBodyCellEditContext context,
+                                               final int expectedUiRowIndex,
+                                               final int expectedUiColumnIndex,
+                                               final double expectedCellHeight,
+                                               final double expectedCellWidth,
+                                               final double expectedAbsoluteCellY,
+                                               final double expectedAbsoluteCellX,
+                                               final double expectedClipMinY,
+                                               final double expectedClipMinX) {
+        assertEquals(expectedUiRowIndex, context.getRowIndex());
+        assertEquals(expectedUiColumnIndex, context.getColumnIndex());
+        assertEquals(expectedCellHeight, context.getCellHeight(), 0.0);
+        assertEquals(expectedCellWidth, context.getCellWidth(), 0.0);
+        assertEquals(expectedAbsoluteCellY, context.getAbsoluteCellY(), 0.0);
+        assertEquals(expectedAbsoluteCellX, context.getAbsoluteCellX(), 0.0);
+        assertEquals(expectedClipMinY, context.getClipMinY(), 0.0);
+        assertEquals(expectedClipMinX, context.getClipMinX(), 0.0);
+    }
 }
