@@ -11,7 +11,7 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
-*/
+ */
 package org.guvnor.common.services.project.backend.server;
 
 import java.net.URI;
@@ -30,6 +30,9 @@ import org.guvnor.common.services.project.service.ModuleService;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
+import org.guvnor.structure.organizationalunit.config.SpaceConfigStorage;
+import org.guvnor.structure.organizationalunit.config.SpaceConfigStorageRegistry;
+import org.guvnor.structure.organizationalunit.config.SpaceInfo;
 import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryEnvironmentConfigurations;
@@ -41,8 +44,9 @@ import org.junit.runner.RunWith;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.mockito.invocation.InvocationOnMock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
 import org.uberfire.backend.server.util.Paths;
 import org.uberfire.backend.vfs.Path;
@@ -52,21 +56,13 @@ import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.spaces.Space;
 import org.uberfire.spaces.SpacesAPI;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.*;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.doAnswer;
-import static org.mockito.Mockito.doReturn;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.times;
-import static org.mockito.Mockito.verify;
-import static org.mockito.Mockito.when;
+import static org.mockito.Mockito.*;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class WorkspaceProjectMigrationServiceImplTest {
 
     private static final String NIOGIT_PATH = "/home/someone/somehwere/.niogit";
@@ -113,8 +109,11 @@ public class WorkspaceProjectMigrationServiceImplTest {
     @Mock
     private Space space;
 
-    @Captor
-    private ArgumentCaptor<Path> pathArgumentCaptor;
+    @Mock
+    private SpaceConfigStorage spaceConfigStorage;
+
+    @Mock
+    private SpaceConfigStorageRegistry spaceConfigStorageRegistry;
 
     @Captor
     private ArgumentCaptor<NewProjectEvent> newProjectEventArgumentCaptor;
@@ -128,19 +127,23 @@ public class WorkspaceProjectMigrationServiceImplTest {
     @Before
     public void setUp() throws Exception {
 
-        doReturn(mock(WorkspaceProject.class)).when(workspaceProjectService).resolveProject(any(Repository.class));
+        SpaceInfo spaceInfo = mock(SpaceInfo.class);
+        doAnswer(invocation -> null).when(spaceInfo).removeRepository(any());
+        doAnswer(invocation -> null).when(spaceInfo).getRepositories(any());
+        doReturn(spaceInfo).when(spaceConfigStorage).loadSpaceInfo();
+        when(spaceConfigStorageRegistry.get(any())).thenReturn(spaceConfigStorage);
 
-        doAnswer(new Answer<org.uberfire.java.nio.file.Path>() {
-            @Override
-            public org.uberfire.java.nio.file.Path answer(InvocationOnMock invocationOnMock) throws Throwable {
-                return Paths.convert(PathFactory.newPath("file",
-                                                         invocationOnMock.getArguments()[0].toString()));
-            }
-        }).when(ioService).get(any(URI.class));
+        doReturn(mock(WorkspaceProject.class)).when(workspaceProjectService).resolveProject(Mockito.<Repository>any());
 
-        when(pathUtil.normalizePath(any())).then(inv -> inv.getArgumentAt(0, Path.class));
-        when(pathUtil.convert(any(Path.class))).then(inv -> {
-            final Path path = inv.getArgumentAt(0, Path.class);
+        doAnswer((Answer<org.uberfire.java.nio.file.Path>) invocationOnMock ->
+                Paths.convert(PathFactory.newPath("file",
+                                                  invocationOnMock.getArguments()[0].toString()))).when(ioService).get(any());
+
+        when(pathUtil.normalizePath(any())).then(inv -> inv.getArgument(0,
+                                                                          Path.class));
+        when(pathUtil.convert(Mockito.<Path>any())).then(inv -> {
+            final Path path = inv.getArgument(0,
+                                                Path.class);
 
             final org.uberfire.java.nio.file.Path retVal = mock(org.uberfire.java.nio.file.Path.class);
             when(retVal.toUri()).then(inv1 -> URI.create(path.toURI()));
@@ -149,19 +152,25 @@ public class WorkspaceProjectMigrationServiceImplTest {
         });
         when(pathUtil.getNiogitRepoPath(any())).thenReturn(NIOGIT_PATH);
 
-        service = new WorkspaceProjectMigrationServiceImpl(workspaceProjectService,
-                                                           repositoryService,
-                                                           organizationalUnitService,
-                                                           pathUtil,
-                                                           newProjectEvent,
-                                                           moduleService);
+        service = spy(new WorkspaceProjectMigrationServiceImpl(workspaceProjectService,
+                                                               repositoryService,
+                                                               organizationalUnitService,
+                                                               pathUtil,
+                                                               newProjectEvent,
+                                                               moduleService,
+                                                               spaceConfigStorageRegistry));
+
+        doAnswer(invocation -> null).when(service).cleanupOrigin(any());
 
         legacyMasterBranch = mockBranch("legacyMasterBranch");
         legacyDevBranch = mockBranch("legacyDevBranch");
 
-        when(legacyDevBranchProject1RootPath.toURI()).thenReturn(uri("legacyDevBranch", "legacyProject1"));
-        when(legacyDevBranchProject2RootPath.toURI()).thenReturn(uri("legacyDevBranch", "legacyProject2"));
-        when(legacyMasterBranchProject1RootPath.toURI()).thenReturn(uri("legacyMasterBranch", "legacyProject1"));
+        when(legacyDevBranchProject1RootPath.toURI()).thenReturn(uri("legacyDevBranch",
+                                                                     "legacyProject1"));
+        when(legacyDevBranchProject2RootPath.toURI()).thenReturn(uri("legacyDevBranch",
+                                                                     "legacyProject2"));
+        when(legacyMasterBranchProject1RootPath.toURI()).thenReturn(uri("legacyMasterBranch",
+                                                                        "legacyProject1"));
 
         final Repository legacyRepository = mockLegacyRepository();
 
@@ -179,7 +188,8 @@ public class WorkspaceProjectMigrationServiceImplTest {
         service.migrate(legacyWorkspaceProject);
     }
 
-    private String uri(final String branch, final String repo) {
+    private String uri(final String branch,
+                       final String repo) {
         return "git://" + branch + "@" + SPACE + "/" + REPO + "/" + repo;
     }
 
@@ -194,29 +204,42 @@ public class WorkspaceProjectMigrationServiceImplTest {
         final List<RepositoryEnvironmentConfigurations> allValues = configsCaptor.getAllValues();
         final Set<String> observedSubdirectories = new HashSet<>();
         allValues.forEach(configs -> {
-            assertEquals(NIOGIT_PATH, assertInstanceOf(configs.getOrigin(), String.class));
-            assertFalse(assertInstanceOf(configs.getInit(), Boolean.class));
-            assertFalse(assertInstanceOf(configs.getMirror(), Boolean.class));
+            assertEquals(NIOGIT_PATH,
+                         assertInstanceOf(configs.getOrigin(),
+                                          String.class));
+            assertFalse(assertInstanceOf(configs.getInit(),
+                                         Boolean.class));
+            assertFalse(assertInstanceOf(configs.getMirror(),
+                                         Boolean.class));
 
-            final String subdirectory = assertInstanceOf(configs.getSubdirectory(), String.class);
+            final String subdirectory = assertInstanceOf(configs.getSubdirectory(),
+                                                         String.class);
             observedSubdirectories.add(subdirectory);
 
             @SuppressWarnings("unchecked")
-            final List<String> branches = assertInstanceOf(configs.getBranches(), List.class);
+            final List<String> branches = assertInstanceOf(configs.getBranches(),
+                                                           List.class);
             final List<String> expectedBranches;
             if (subdirectory.equals("legacyProject1")) {
-                expectedBranches = Arrays.asList("legacyMasterBranch", "legacyDevBranch");
+                expectedBranches = Arrays.asList("legacyMasterBranch",
+                                                 "legacyDevBranch");
             } else if (subdirectory.equals("legacyProject2")) {
                 expectedBranches = Arrays.asList("legacyDevBranch");
             } else {
                 throw new AssertionError("Unrecognized subdirectory: " + subdirectory);
             }
 
-            assertEquals("Unexpected branches for subdirectory " + subdirectory, new HashSet<>(expectedBranches), new HashSet<>(branches));
+            verify(service,
+                   times(2)).cleanupOrigin(any());
+
+            assertEquals("Unexpected branches for subdirectory " + subdirectory,
+                         new HashSet<>(expectedBranches),
+                         new HashSet<>(branches));
         });
 
-        assertEquals(new HashSet<>(Arrays.asList("legacyProject1", "legacyProject2")), observedSubdirectories);
-
+        assertEquals(new HashSet<>(Arrays.asList("legacyProject1",
+                                                 "legacyProject2")),
+                     observedSubdirectories);
     }
 
     @Test
@@ -230,7 +253,8 @@ public class WorkspaceProjectMigrationServiceImplTest {
         assertNotNull(allValues.get(1).getWorkspaceProject());
     }
 
-    private <T> T assertInstanceOf(Object value, Class<T> clazz) {
+    private <T> T assertInstanceOf(Object value,
+                                   Class<T> clazz) {
         assertTrue(clazz.isInstance(value));
 
         return clazz.cast(value);
@@ -280,6 +304,8 @@ public class WorkspaceProjectMigrationServiceImplTest {
 
         when(legacyRepository.getDefaultBranch()).thenReturn(Optional.of(legacyMasterBranch));
 
+        doReturn(space).when(legacyRepository).getSpace();
+
         return legacyRepository;
     }
 
