@@ -41,7 +41,7 @@ import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.client.promise.Promises;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.promise.SyncPromises;
@@ -65,6 +65,12 @@ import static org.mockito.Mockito.when;
 @RunWith(MockitoJUnitRunner.class)
 public class ProjectControllerTest {
 
+    private static final String SHOW_PROJECT_TOOLBAR = "projecttoolbar.show";
+
+    private static final String SHOW_METRICS_TAB = "metricstab.show";
+
+    private static final String SHOW_CHANGEREQUEST_TAB = "changerequesttab.show";
+
     @Mock
     private AuthorizationManager authorizationManager;
 
@@ -89,6 +95,27 @@ public class ProjectControllerTest {
                                                       promises));
     }
 
+    @Test
+    public void userCanViewMetricsTabTest() {
+        when(authorizationManager.authorize(SHOW_METRICS_TAB,
+                                            user)).thenReturn(true);
+        assertTrue(projectController.canViewMetricsTab());
+    }
+
+    @Test
+    public void userCanViewMChangeRequestTabTest() {
+        when(authorizationManager.authorize(SHOW_CHANGEREQUEST_TAB,
+                                            user)).thenReturn(true);
+        assertTrue(projectController.canViewChangeRequestTab());
+    }
+
+    @Test
+    public void userCanViewProjectToolbarTest() {
+        when(authorizationManager.authorize(SHOW_PROJECT_TOOLBAR,
+                                            user)).thenReturn(true);
+        assertTrue(projectController.canViewProjectToolbar());
+    }
+
     @Test
     public void userCanCreateProjectTest() {
         final WorkspaceProject project = getProject();
@@ -138,9 +165,6 @@ public class ProjectControllerTest {
     @Test
     public void userCanNotReadProjectTest() {
         final WorkspaceProject project = getProject();
-        when(authorizationManager.authorize(project.getRepository(),
-                                            RepositoryAction.READ,
-                                            user)).thenReturn(false);
         doReturn(false).when(projectController).userIsAtLeast(any(),
                                                               any());
         assertFalse(projectController.canCreateProjects(project.getOrganizationalUnit()));
@@ -708,7 +732,7 @@ public class ProjectControllerTest {
         branchPermissions.put("branch2", new BranchPermissions("branch2", branch2PermissionsByRole));
 
         doReturn(Optional.of(new Contributor("contributor", ContributorType.CONTRIBUTOR))).when(projectController).getUserContributor(any());
-        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(anyString(), anyString(), anyList());
+        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(any(), any(), anyList());
 
         projectController.getUpdatableBranches(project).then(branches -> {
             assertEquals(0, branches.size());
@@ -734,7 +758,7 @@ public class ProjectControllerTest {
         branchPermissions.put("branch2", new BranchPermissions("branch2", branch2PermissionsByRole));
 
         doReturn(Optional.of(new Contributor("contributor", ContributorType.CONTRIBUTOR))).when(projectController).getUserContributor(any());
-        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(anyString(), anyString(), anyList());
+        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(any(), any(), anyList());
 
         projectController.getUpdatableBranches(project).then(branches -> {
             assertEquals(1, branches.size());
@@ -761,7 +785,7 @@ public class ProjectControllerTest {
         branchPermissions.put("branch2", new BranchPermissions("branch2", branch2PermissionsByRole));
 
         doReturn(Optional.of(new Contributor("contributor", ContributorType.CONTRIBUTOR))).when(projectController).getUserContributor(any());
-        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(anyString(), anyString(), anyList());
+        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(any(), any(), anyList());
 
         projectController.getReadableBranches(project).then(branches -> {
             assertEquals(2, branches.size());
@@ -789,7 +813,7 @@ public class ProjectControllerTest {
         branchPermissions.put("branch2", new BranchPermissions("branch2", branch2PermissionsByRole));
 
         doReturn(Optional.of(new Contributor("contributor", ContributorType.CONTRIBUTOR))).when(projectController).getUserContributor(any());
-        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(anyString(), anyString(), anyList());
+        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(any(), any(), anyList());
 
         projectController.getReadableBranches(project).then(branches -> {
             assertEquals(1, branches.size());
@@ -816,7 +840,7 @@ public class ProjectControllerTest {
         branchPermissions.put("branch2", new BranchPermissions("branch2", branch2PermissionsByRole));
 
         doReturn(Optional.of(new Contributor("contributor", ContributorType.CONTRIBUTOR))).when(projectController).getUserContributor(any());
-        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(anyString(), anyString(), anyList());
+        doReturn(branchPermissions).when(projectPermissionsService).loadBranchPermissions(any(), any(), anyList());
 
         projectController.getReadableBranches(project).then(branches -> {
             assertEquals(0, branches.size());
@@ -848,7 +872,6 @@ public class ProjectControllerTest {
         doReturn(organizationalUnit).when(project).getOrganizationalUnit();
         doReturn(space).when(project).getSpace();
         doReturn(branch).when(project).getBranch();
-        doReturn(Optional.of(branch)).when(repository).getBranch("branch");
         doReturn(Optional.of(branch2)).when(repository).getBranch("branch2");
         doReturn(Arrays.asList(branch, branch2)).when(repository).getBranches();
         doReturn(mock(Module.class)).when(project).getMainModule();
