@@ -27,9 +27,9 @@ import org.guvnor.structure.client.editors.repository.clone.answer.RsCreateRepos
 import org.guvnor.structure.client.editors.repository.clone.answer.RsCreateRepositoryFailAnswer;
 import org.guvnor.structure.client.editors.repository.clone.answer.RsNormalizedNameAnswer;
 import org.guvnor.structure.events.AfterCreateOrganizationalUnitEvent;
-import org.guvnor.structure.events.AfterDeleteOrganizationalUnitEvent;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
+import org.guvnor.structure.organizationalunit.RemoveOrganizationalUnitEvent;
 import org.guvnor.structure.organizationalunit.impl.OrganizationalUnitImpl;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryAlreadyExistsException;
@@ -49,7 +49,7 @@ import org.junit.runner.RunWith;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.client.mvp.PlaceManager;
 
 import static org.junit.Assert.*;
@@ -333,7 +333,6 @@ public class CloneMavenRepositoryPresenterTest {
         when(repositoryPreferences.isOUMandatory()).thenReturn(true);
         when(view.isGitUrlEmpty()).thenReturn(false);
         when(view.getGitUrl()).thenReturn(REPO_URL);
-        when(view.getName()).thenReturn(REPO_NAME);
         when(view.getSelectedOrganizationalUnit()).thenReturn("");
 
         presenter = new CloneRepositoryPresenter(repositoryPreferences,
@@ -352,8 +351,6 @@ public class CloneMavenRepositoryPresenterTest {
     public void testCloneNoUrl() {
         when(repositoryPreferences.isOUMandatory()).thenReturn(true);
         when(view.isGitUrlEmpty()).thenReturn(true);
-        when(view.getGitUrl()).thenReturn("");
-        when(view.getName()).thenReturn(REPO_NAME);
         when(view.getSelectedOrganizationalUnit()).thenReturn(ORG_UNIT_ONE);
 
         presenter = new CloneRepositoryPresenter(repositoryPreferences,
@@ -388,7 +385,7 @@ public class CloneMavenRepositoryPresenterTest {
     public void testDeleteOUEvent() {
         final OrganizationalUnit ou = new OrganizationalUnitImpl("ou1",
                                                                  "ou");
-        presenter.onDeleteOrganizationalUnit(new AfterDeleteOrganizationalUnitEvent(ou));
+        presenter.onDeleteOrganizationalUnit(new RemoveOrganizationalUnitEvent(ou, "admin"));
 
         verify(view,
                times(1)).deleteOrganizationalUnit(ou);
