@@ -19,6 +19,7 @@ package org.uberfire.client.mvp;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import java.util.function.Consumer;
 import javax.enterprise.event.Event;
 
 import org.jboss.errai.ioc.client.container.SyncBeanDef;
@@ -30,7 +31,7 @@ import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.Spy;
 import org.mockito.invocation.InvocationOnMock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
 import org.uberfire.client.workbench.PanelManager;
 import org.uberfire.client.workbench.WorkbenchServicesProxy;
@@ -103,6 +104,10 @@ public class PerspectiveManagerTest {
         when(oz.getDefaultPerspectiveLayout()).thenReturn(ozDefinition);
         when(oz.getIdentifier()).thenReturn("oz_perspective");
         when(oz.isTransient()).thenReturn(true);
+        doAnswer((Answer<Void>) invocationOnMock -> {
+            invocationOnMock.getArgument(0, Consumer.class).accept(null);
+            return null;
+        }).when(oz).getMenus(any());
 
         doWhenFinished = mock(ParameterizedCommand.class);
         doAfterFetch = spy(new ParameterizedCommand<PerspectiveDefinition>() {
@@ -112,7 +117,8 @@ public class PerspectiveManagerTest {
         });
         doWhenFinishedSave = mock(Command.class);
 
-        fetchCommand = spy(perspectiveManager.new FetchPerspectiveCommand(oz,
+        fetchCommand = spy(perspectiveManager.new FetchPerspectiveCommand(pr,
+                                                                          oz,
                                                                           doAfterFetch));
 
         // simulate "finished saving" callback on wbServices.save()
@@ -123,9 +129,9 @@ public class PerspectiveManagerTest {
                 callback.execute();
                 return null;
             }
-        }).when(wbServices).save(any(String.class),
-                                 any(PerspectiveDefinition.class),
-                                 any(Command.class));
+        }).when(wbServices).save(any(),
+                                 any(),
+                                 any());
 
         // simulate "no saved state found" result on wbServices.loadPerspective()
         doAnswer(new Answer<Void>() {
@@ -135,14 +141,14 @@ public class PerspectiveManagerTest {
                 callback.execute(null);
                 return null;
             }
-        }).when(wbServices).loadPerspective(anyString(),
-                                            any(ParameterizedCommand.class));
+        }).when(wbServices).loadPerspective(any(),
+                                            any());
 
         // XXX should look at why PanelManager needs to return an alternative panel sometimes.
         // would be better if addWorkbenchPanel returned void.
-        when(panelManager.addWorkbenchPanel(any(PanelDefinition.class),
-                                            any(PanelDefinition.class),
-                                            any(Position.class))).thenAnswer(new Answer<PanelDefinition>() {
+        when(panelManager.addWorkbenchPanel(any(),
+                                            any(),
+                                            any())).thenAnswer(new Answer<PanelDefinition>() {
             @Override
             public PanelDefinition answer(InvocationOnMock invocation) {
                 return (PanelDefinition) invocation.getArguments()[1];
@@ -190,7 +196,6 @@ public class PerspectiveManagerTest {
 
         PerspectiveActivity kansas = mock(PerspectiveActivity.class);
         when(kansas.getDefaultPerspectiveLayout()).thenReturn(kansasDefinition);
-        when(kansas.getIdentifier()).thenReturn("kansas_perspective");
         when(kansas.isTransient()).thenReturn(true);
 
         perspectiveManager.switchToPerspective(pr,
@@ -272,8 +277,6 @@ public class PerspectiveManagerTest {
                                southWestPanel);
 
         // we assume this will be set correctly (verified elsewhere)
-        when(panelManager.getRoot()).thenReturn(ozDefinition.getRoot());
-
         perspectiveManager.switchToPerspective(pr,
                                                oz,
                                                doWhenFinished);
@@ -345,7 +348,6 @@ public class PerspectiveManagerTest {
     @Test
     public void fetchPerspectivesForTransientPerspectivesShouldAlwaysLoadDefaultLayoutTest() throws Exception {
 
-        when(fetchCommand.isAValidDefinition(any())).thenReturn(true);
         fetchCommand.execute();
 
         assertEquals(oz,
@@ -366,8 +368,6 @@ public class PerspectiveManagerTest {
 
     @Test
     public void isAnInvalidPerspectiveDefinitionTest() throws Exception {
-        when(activityBeansCache.hasActivity(any())).thenReturn(true);
-
         assertFalse(fetchCommand.isAValidDefinition(null));
     }
 
