@@ -16,13 +16,15 @@
 
 package org.uberfire.client.workbench.widgets.menu.megamenu;
 
+import java.util.function.Consumer;
+
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.client.mvp.ActivityManager;
 import org.uberfire.client.mvp.PerspectiveActivity;
 import org.uberfire.client.mvp.PerspectiveManager;
@@ -49,6 +51,7 @@ import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.isNull;
+import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
@@ -132,8 +135,6 @@ public class WorkbenchMegaMenuStandalonePresenterTest {
         final String perspectiveId = "perspectiveId";
         final String label = "perspectiveLabel";
         final Menus menus = MenuFactory.newSimpleItem(label).perspective(perspectiveId).endMenu().build();
-        when(authzManager.authorize(menus.getItems().get(0),
-                                    identity)).thenReturn(true);
 
         presenter.addMenus(menus);
 
@@ -156,8 +157,10 @@ public class WorkbenchMegaMenuStandalonePresenterTest {
         final PerspectiveActivity activity = mock(PerspectiveActivity.class);
         final PlaceRequest placeRequest = mock(PlaceRequest.class);
 
-        when(activity.getIdentifier()).thenReturn(perspectiveId);
-        when(activity.getMenus()).thenReturn(contextMenus);
+        doAnswer(invocationOnMock -> {
+            invocationOnMock.getArgument(0, Consumer.class).accept(contextMenus);
+            return null;
+        }).when(activity).getMenus(any());
         when(activity.isType(ActivityResourceType.PERSPECTIVE.name())).thenReturn(true);
         when(authzManager.authorize(contextMenus.getItems().get(0),
                                     identity)).thenReturn(true);
